pub enum CorrelationState<K, Route> {
Pending {
key: K,
reply_to: Route,
},
Completed {
key: K,
},
Cancelled {
key: K,
},
}Expand description
Complete retained lifecycle of one correlation key.
Variants
Pending
The key owns one reply recipient and may accept resolution or cancel.
Completed
The key resolved and later replies are stale.
Fields

key: KCancelled
The key was cancelled and later replies are stale.
Fields

key: KAuto Trait Implementations
impl<K, Route> Freeze for CorrelationState<K, Route>
impl<K, Route> RefUnwindSafe for CorrelationState<K, Route>where
K: RefUnwindSafe,
Route: RefUnwindSafe,
impl<K, Route> Send for CorrelationState<K, Route>
impl<K, Route> Sync for CorrelationState<K, Route>
impl<K, Route> Unpin for CorrelationState<K, Route>
impl<K, Route> UnsafeUnpin for CorrelationState<K, Route>where
K: UnsafeUnpin,
Route: UnsafeUnpin,
impl<K, Route> UnwindSafe for CorrelationState<K, Route>where
K: UnwindSafe,
Route: UnwindSafe,