DeduplicatorOutcome

Enum DeduplicatorOutcome 

pub enum DeduplicatorOutcome<K, T> {
    Delivered {
        key: K,
        evicted: Option<K>,
    },
    Duplicate {
        key: K,
        value: T,
    },
}
Factual outcome of one keyed delivery attempt.

Variants



Delivered

The key was new, the value was delivered, and retention was committed.

Fields

key: K

Accepted key.

evicted: Option<K>

Oldest key removed to remain within capacity, if any.



Duplicate

The key is retained, so ownership of the undelivered value is returned.

Fields

key: K

Duplicate key.

value: T

Undelivered value.