OrderGateOutcome

Enum OrderGateOutcome 

pub enum OrderGateOutcome<K, T> {
    Held {
        key: K,
        held: usize,
    },
    Delivered {
        key: K,
    },
    Duplicate {
        key: K,
        value: T,
    },
    Opened {
        through: K,
        released: usize,
        held: usize,
    },
    StaleOpening {
        requested: K,
        current: K,
    },
}
Factual result of one gate operation.

Variants



Held

A value is retained until the watermark reaches its key.

Fields

key: K

Accepted key.

held: usize

Current retained count.



Delivered

The key is already open, so the value was delivered immediately.

Fields

key: K

Accepted key.



Duplicate

Another retained value already owns this key.

Fields

key: K

Rejected key.

value: T

Rejected owned value.



Opened

One monotonic opening was committed.

Fields

through: K

New watermark.

released: usize

Number of retained values released in key order.

held: usize

Number still held.



StaleOpening

An opening attempted to move the watermark backwards or repeat it.

Fields

requested: K

Rejected watermark.

current: K

Current watermark.