pub enum OverflowPolicy {
Reject,
DropOldest,
DropNewest,
}Expand description
Exhaustive behavior-owned policy when a Buffer is full.
Variants
Reject
Refuse the offered value and retain the complete queue.
DropOldest
Return the oldest accepted value, then accept the new value.
DropNewest
Return the newly offered value without changing the queue.