RouterMessage

Enum RouterMessage 

pub enum RouterMessage<Route: DeliveryRoute + Clone + PartialEq, R: RoutingStrategy<Route>> {
    Add(Route),
    Remove(Route),
    Route(<Route::Protocol as Protocol>::Msg),
    Observe(R::Observation),
}
One command accepted by Router.

Membership changes are processed in mailbox order. Route transfers ownership of one destination-protocol message to the router. Duplicate members are inert and removal preserves the relative order of survivors.

Variants



Add(Route)

Add one eligible recipient if it is not already present.



Remove(Route)

Remove one eligible recipient if present.



Route(<Route::Protocol as Protocol>::Msg)

Select recipient(s) and emit typed deliveries.



Observe(R::Observation)

Deliver one statically selected policy observation.