SequencerOutcome

Enum SequencerOutcome 

pub enum SequencerOutcome<T> {
    Accepted {
        released: usize,
        buffered: usize,
    },
    Stale {
        sequence: Sequence,
        value: T,
        expected: Sequence,
    },
    Duplicate {
        value: T,
        sequence: Sequence,
    },
    Exhausted {
        sequence: Sequence,
        value: T,
    },
}
Factual result of offering one sequenced value.

Variants



Accepted

The value was accepted and this many contiguous values were delivered.

Fields

released: usize

Number released by this offer, including the offered value when it filled the current position.

buffered: usize

Number still retained beyond a gap.



Stale

The position precedes the current expected position.

Fields

sequence: Sequence

Rejected sequence position.

value: T

Rejected value, returned without cloning or loss.

expected: Sequence

Current expected position.



Duplicate

A value already occupies this future position.

Fields

value: T

Rejected value, returned without replacing the accepted value.

sequence: Sequence

Occupied position.



Exhausted

The sequence domain has no representable successor.

Fields

sequence: Sequence

Rejected sequence position.

value: T

Rejected value.