RouteKey

Trait RouteKey 

pub trait RouteKey<K> {
    // Required method
    fn route_key(&self) -> &K;
}
Exposes the statically known routing key of one destination message.

Required Methods

fn route_key(&self) -> &K

Borrow the key used only by the selected hash policy.

Implementors